/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function tikzStrings = add_color_defines(attributes)
// Generate color definition strings
//
// Syntax
// tikzStrings = add_color_defines(attributes)
//
// Parameters
//      attributes: struct containing graphical elements
//      tikzStrings: column vector containing generated strings
//
// Description
// Grabs the color names from the attributes struct and translates it to
// RGB triples. The color definition is added in the form
// \definecolor{rgb}{red val, green val, blue val}.
//
// Examples
// choose_plot_example("simple");
// attributes = gather_graphic_attributes();
// colorString = add_color_defines(attributes);
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("attributes", "l")
        message = "%s: please provide an input argument!\n";
        error(msprintf(message, "add_color_defines"))
    end

    if ~isstruct(attributes)
        message = "%s: input argument is not a struct!\n";
        error(msprintf(message, "add_color_defines"))
    end

    // Load internals
    path = get_function_path("add_color_defines");
    path = fullpath(fullfile(fileparts(path)));
    xs2tikzinternalslib = lib(fullfile(path, "internals"));

    tikzStrings = [];
    colors = unique(find_colors(attributes));

    rgbValues = [];

    for index = 1:size(colors, "c")
        rgbValues($+1, :) =  name2rgb(colors(index));
        tikzStrings($+1) = msprintf("\\definecolor{%s}{rgb}{%f,%f,%f}%%\n",...
                                    colors(index), ...
                                    rgbValues(index, 1)/255, ...
                                    rgbValues(index, 2)/255, ...
                                    rgbValues(index, 3)/255);
    end

    tikzStrings($+1) = msprintf("\n");
endfunction
