/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function tikzStrings = add_environment_end(env)
// Generate an environment closing block string
//
// Syntax
// tikzString = add_environment_end(env)
//
// Parameters
//      env: a string resembling a environment like "tikzpicture"
//      tikzStrings: column vector containing generated strings
//
// Description
// Depending on "env", this function generates an closing block string.
// Currently supported environments are:
// tikzpicture
// axis
// document
// addplot
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("env", "l")
        message = "%s: please provide an input argument!\n";
        error(msprintf(message, "add_environment_end"))
    end

    if typeof(env) ~= "string"
        message = "%s: input argument is not of type string!\n";
        error(msprintf(message, "add_environment_end"))
    end

    select env
        case "tikzpicture" then
            tikzStrings = msprintf("\\end{%s}\n", env);
        case "axis" then
            tikzStrings = msprintf("\\end{%s}\n", env);
        case "document" then
            tikzStrings = msprintf("\\end{%s}\n", env);
        case "addplot" then
            tikzStrings = msprintf("};");
        else
            message = "%s: not a valid environment.\n";
            error(msprintf(message, "add_environment_end"))
    end
endfunction
