/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function tikzStrings = add_graphical_element(env, data)
// Add data from graphical element for environment to tikzStrings
//
// Syntax
// tikzStrings = add_graphical_element(env, data)
//
// Parameters
//      env: a string resembling the targeted environment for data adding
//      data: a nx2 matrix containing the elements data as tuples
//      tikzStrings: column vector containing generated strings
//
// Description
// Generates a string vector with the data elements as tuples for the corresponding
// environment. Currently supported is:
// addplot
//
// Examples
// add_graphical_element("addplot", [(1,2);(2,3)])
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("env", "l") || ~isdef("data", "l")
        message = "%s: insufficient number of input arguments, 2 expected!\n";
        error(msprintf(message, "add_graphical_element"))
    end

    if typeof(env) ~= "string"
        message = "%s: input argument env is not of type string!\n";
        error(msprintf(message, "add_graphical_element"))
    end

    tikzStrings = [];

    select env
        case "addplot" then
            tikzStrings($+1) = msprintf("coordinates {");
            for index = 1:size(data, "r")
                tikzStrings($+1) = msprintf("(%f, %f)", data(index, 1), data(index, 2));
            end
        else
            message = "%s: unknown environment string given.\n";
            error(msprintf(message, "add_graphical_element"))
    end

endfunction
