/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function tikzString = add_legendentry(text)
// Add legend entry for graphical element tikzStrings
//
// Syntax
// tikzStrings = add_legendentry(text)
//
// Parameters
//      text: a string which will be printed in the legend part
//      tikzStrings: column vector containing generated strings
//
// Description
// Generates a string with an \addlegendentry.
//
// Examples
// ts = add_legendentry("sinh(x)")
//
// Authors
// Manuel Csapo, 2018
if ~isdef("text", "l")
    message = "%s: please provide an input argument!\n";
    error(msprintf(message, "add_legendentry"))
end

if typeof(text) ~= "string"
    message = "%s: input argument must be a string!\n";
    error(msprintf(message, "add_legendentry"))
end

tikzString = msprintf("\\addlegendentry{%s}", text)

endfunction
