/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function [f, a] = choose_plot_example(example)
// Interface function for plotting examples
//
// Syntax
// [f, a] = choose_plot_example(example);
//
// Parameters
//      example: string with name of example
//      f, a: figure and axis handles
//
// Description
// With this function it's possible to choose which plotting example
// should be used and displayed.
// Following strings are supported for the parameter example:
// 'simple' = plot_example_simple_graph()
// 'cmap' = plot_example_color_map()
// 'subplot' = plot_example_subplots()
// 'champ' = plot_example3d_champ()
// 'mesh' = plot_example3d_mesh()

if ~isdef("example", "l")
    message = "%s: please provide an input argument!\n";
    error(msprintf(message, "choose_plot_example"))
end

if typeof(example) ~= "string"
    message = "%s: input argument is not a string!\n";
    error(msprintf(message, "choose_plot_example"))
end

select example
    case "simple" then
        [f, a] = plot_example_simple_graph();
    case "cmap" then
        [f, a] = plot_example_color_map();
    case "subplot" then
        [f, a] = plot_example_subplots();
    case "champ" then
        [f, a] = plot_example_champ();
    case "mesh" then
        [f, a] = plot_example_mesh();
    else
        message = "%s: example %s not supported.\n";
        error(msprintf(message, "choose_plot_example", example))
end

endfunction
