/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function attributes = create_figure_struct(attributes)
// Create a struct for the figure information
//
// Syntax
// attributes = create_figure_struct(attributes)
//
// Parameters
//      attributes: struct for holding the gathered plot data
//
// Description
// Creates a struct figure in attributes holding size, colormap and handle. The
// input parameter should be an empty struct.
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("attributes", "l")
        message = "%s: please provide an input argument!\n";
        error(msprintf(message, "create_figure_struct"))
    end

    if ~isstruct(attributes)
        message = "%s: input argument is not a struct!\n"
        error(msprintf(message, "create_figure_struct"))
    end

    // Load internals
    path = get_function_path("create_figure_struct");
    path = fullpath(fullfile(fileparts(path)));
    xs2tikzinternalslib = lib(fullfile(path, "internals"));

    attributes.figure = struct( "handle", gcf(), ...
                                "size", get_figure_size(gcf()), ...
                                "colormap", get_colormap(gcf()) ...
                              );
endfunction
