/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function fields = field_iterator(iterableStruct)
// Return all fields from a struct
//
// Syntax
// fields = field_iterator(iterableStruct)
//
// Parameters
// iterableStruct: struct where we want to extract fields from
// fields: list containing extracted fields
//
// Description
// This function is mainly used as a helper for iterating over structs via for loops.
//
// Examples
// choose_plot_example("simple");
// attributes = gather_graphic_attributes();
// for field = field_iterator(attributes)
//      disp(field)
// end
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("iterableStruct", "l")
        message = "%s: please provide an input argument!\n";
        error(msprintf(message, "field_iterator"))
    end

    if ~(isstruct(iterableStruct) || iscell(iterableStruct))
        message = "%s: input argument is neither a struct nor a cell!\n";
        error(msprintf(message, "field_iterator"))
    end

    if iscell(iterableStruct) && (size(iterableStruct, "c") > 1)
        message = "%s: the given iterableStruct has more dimensions then we are able to handle!\n";
        error(msprintf(message, "field_iterator"))
    end

    fields = list();

    if isempty(iterableStruct)
      return;
    end

    if isstruct(iterableStruct)
       names = fieldnames(iterableStruct)';
       for name = names
           fields($+1) = getfield(name, iterableStruct);
       end
    elseif iscell(iterableStruct)
       fields = iterableStruct{:};
    end
endfunction
