/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function textString = find_legendentry(graphicalElement, legends)
// Find corresponding legend entry for graphical element
//
// Syntax
// textString = find_legendentry(graphicalElement, legends)
//
// Parameters
//      graphicalElement: struct with element for which the legend entry shall be found
//      legends: cell containing all legends
//      textString: legend entry text string found
//
// Description
// Find the corresponding legend entry for graphical element in legends and returns
// the text string.
//
// Examples
// choose_plot_example("simple");
// attributes = gather_graphic_attribues();
// ts = find_legendentry(attributes.polylines{1} attributes.legends)
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("graphicalElement", "l") || ~isdef("legends", "l")
        message = "%s: insufficient number of input arguments, 2 expected!\n";
        error(msprintf(message, "find_legendentry"))
    end

    if isempty(graphicalElement) || isempty(legends)
         textString = "";
         return;
    end

    if ~isstruct(graphicalElement) || ~iscell(legends)
        message = "%s: graphicalElement must be a struct, legends a cell.\n";
        error(msprintf(message, "find_legendentry"))
    end

    for legend = legends{:}
        // Assumption: every polyline can only belong to one legend
        index = find(legend.links == graphicalElement.handle)
        if ~isempty(index)
            textString = legend.text(index);
            break;
        end
    end
endfunction
