/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function attributes = gather_graphic_attributes()
// Gather graphical elements from figure
//
// Syntax
// attributes = gather_graphic_attributes()
//
// Parameters
//      attributes: a struct containing graphical elements
//
// Description
// Gather all necessary graphical elements like figure, axes, entities, colorbars and so on
// and return a struct with fields, which can be converted by using generate_tikz_strings.
// The 'create' functions are called from here.
//
// Examples
// x = linspace(0, 2*%pi, 100);
// plot(x, sin(x), x, cos(x), ':rd');
// title("Sine and cosine");
// xlabel("x");
// ylabel("f(x)");
// legend(['sin(x)', 'cos(x)']);
// //Now use our function to get graphical attributes
// str = gather_graphic_attributes();
// disp(str)
//
// Authors
// Manuel Csapo, 2018
    attributes = struct();
    attributes = create_figure_struct(attributes);
    attributes.axes = create_axes_struct(attributes.figure.handle);
    attributes.legends = create_legends_struct(attributes.axes, attributes.figure.colormap);
    attributes.polylines = create_polylines_struct(attributes.axes, attributes.figure.colormap);
endfunction
