/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function tikzString = generate_color_string(option, value)
// Return a LaTeX color-string
//
// Syntax
// tikzString = generate_color_string(option, value)
//
// Parameters
//      option: string with the LaTeX tag
//      value: string representing value option is set to
//
// Description
// Generate a string with the format &lt;option&gt;=\color{&lt;value&gt;}.
//
// Examples
// opt1 = "font";
// value = "black";
// ts1 = generate_value_string(opt1, value);
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("option", "l") || ~isdef("value", "l")
        message = "%s: insufficient number of input arguments, 2 expected!\n";
        error(msprintf(message, "generate_color_string"))
    end

    if typeof(option) ~= "string"
        message = "%s: input argument option is not a string!\n";
        error(msprintf(message, "generate_color_string"))
    end

    if typeof(value) ~= "string"
        message = "%s: input argument value is not a string!\n";
        error(msprintf(message, "generate_color_string"))
    end

    tikzString = msprintf("%s=\\color{%s}", option, value);
endfunction
