/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function [tikzStringWidth, tikzStringHeight] = generate_dimension_string(width, height)
// Return a matrix of dimension strings
//
// Syntax
// tikzString = generate_dimension_string(option, value)
//
// Parameters
//      option: string like width or height
//      value: a pixel value as string or constant
//
// Description
// Recalculates value from pixel to cm and returns a matrix of strings
// in the form &lt;option&gt;=&lt;value&gt;cm for width and height seperately.
//
// Examples
// x = 360; y = 590;
// ts = generate_dimension_string(x, y);
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("width", "l") || ~isdef("height", "l")
        message = "%s: insufficient number of input arguments, 2 expected!\n";
        error(msprintf(message, "set_text"))
    end

    if ~((typeof(width) == "string")|| (typeof(width) == "constant"))
        message = "%s: input argument width is not a string or constant!\n";
        error(msprintf(message, "set_text"))
    end

    if ~((typeof(height) == "string")|| (typeof(height) == "constant"))
        message = "%s: input argument height is not a string or constant!\n";
        error(msprintf(message, "set_text"))
    end

    if (typeof(width) == "string") && ~isnum(width)
        message = "%s: input argument width must represent a number, mixed strings are not allowed!\n";
        error(msprintf(message, "set_text"))
    end

    if (typeof(height) == "string") && ~isnum(height)
        message = "%s: input argument height must represent a number, mixed strings are not allowed!\n";
        error(msprintf(message, "set_text"))
    end

    if typeof(width) == "string"
        width = strtod(width);
    elseif typeof(height) == "string"
        height = strtod(height)
    end

    // TODO: Refactor to standard size instead of specific
    // (Needed for subplots)
    // length = px * 1 inch (25.4mm) / dpi
    width = width * 2.54/ 122.97;
    height = height * 2.54/ 122.97;

    if width > 15
        ratio = height / width;
        diff = width - 15;
        width = 15;
        height = height - (diff * ratio);
    elseif height > 23
        ratio = height / width;
        diff = height - 23;
        height = 23;
        width = width - (diff * ratio);
    end

    tikzStringWidth = msprintf("width=%.3fcm", width);
    tikzStringHeight = msprintf("height=%.3fcm", height);
endfunction
