/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function tikzString = generate_value_string(option, value)
// Return a string with %d/%s-interpreted value and optional option
//
// Syntax
// tikzString = generate_value_string(option [, value])
//
// Parameters
//      option: string with the LaTeX tag
//      value: option will be set to this
//
// Description
// Generate a string with &lt;option&gt;=&lt;value&gt;.  Value might be a string
// or a constant. If value is omitted, only option is written as string.
//
// Examples
// opt1 = "xmin";
// value = 1;
// ts1 = generate_value_string(opt1, value);
//
// //Options can be given without a value
// opt2 = "scale only axis"
// ts2 = generate_value_string(opt2);
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("option", "l")
        message = "%s: please provide an input argument!\n";
        error(msprintf(message, "generate_value_string"))
    end

    if typeof(option) ~= "string"
        message = "%s: input argument is not a string!\n";
        error(msprintf(message, "generate_value_string"))
    end

    if ~isdef("value", "l")
        tikzString = msprintf("%s", option);
    elseif typeof(value) == "constant"
        // so we use round here since there is some evil magic displaying
        // floats in scilab as intgers sometimes...
        tikzString = msprintf("%s=%d", option, round(value));
    elseif typeof(value) == "string"
        tikzString = msprintf("%s=%s", option, value);
    else
        message = "%s: type of value not supported";
        error(msprintf(message, "generate_value_string"))
    end
endfunction
