/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function tikzStrings = handle_polylines(attributes, axis)
// Add polyline environment and options via addplot
//
// Syntax
// tikzStrings = handle_polylines(attributes);
//
// Parameters
//      attributes: a struct containing graphical elements
//      axis: current axis element
//      tikzStrings: column vector containing the generated strings
//
// Description
// Generates the environment and option strings for all polylines in attributes
// related to the given axis.
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("attributes", "l") || ~isdef("axis", "l")
        message = "%s: insufficient number of input arguments, 2 expected!\n";
        error(msprintf(message, "handle_polylines"))
    end

    if ~isstruct(attributes)
        message = "%s: input argument attributes is not a struct.\n";
        error(msprintf(message, "handle_polylines"));
    end

    if ~isstruct(axis)
        message = "%s: input argument axis is not a struct.\n";
        error(msprintf(message, "handle_polylines"));
    end

    tikzStrings = cell();

    for lineii = size(attributes.polylines, "r"):-1:1
        polyline = attributes.polylines{lineii};
        if polyline.visible == "off"
            continue;
        end
        if polyline.associated_axis == axis.handle
            tikzStrings{$+1} = add_environment_beginning("addplot")';
            tikzStrings{$+1} = add_options("addplot", lineii, attributes);
            tikzStrings{$+1} = add_graphical_element("addplot", polyline.data);
            tikzStrings{$+1} = add_environment_end("addplot")';
            if isfield(polyline, "associated_legend") && ...
               length(polyline.associated_legend) > 0
                tikzStrings{$+1} = add_legendentry(find_legendentry(polyline, attributes.legends));
            end
            tikzStrings{$+1} = "";
        end
    end

    if isempty(tikzStrings)
        tikzStrings = [""];
    else
        tikzStrings = cell2mat(tikzStrings);
    end
endfunction
