/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function tikzStrings = addplot_options(element)
// Generate addplot option entries
//
// Syntax
// tikzStrings = addplot_options(element)
//
// Parameters
//      element: struct containing polyline information
//
// Description
// Generate the addplot option strings as a column vector. Used by add_options.
//
// Authors
// Manuel Csapo, 2018

    if element.visible == "on"
        tikzStrings($+1) = generate_value_string("draw", ...
                                    element.line.color.foreground) + ",";
        tikzStrings($+1) = generate_value_string("fill", ...
                                    element.line.color.background) + ",";
        tikzStrings($+1) = generate_value_string(to_linetype(element.line.style));
        if element.mark.mode == "on"
            tikzStrings($) = tikzStrings($) + ",";
            tikzStrings($+1) = generate_value_string("mark", ...
                                        to_marktype(element.mark.style));
            // set rotation
            select element.mark.style
                case 7 then
                    rotation = "180";
                case 12 then
                    rotation = "90";
                case 13 then
                    rotation = "-90";
            end

            // TODO may refactor this into a generate_mark_options?
            if (element.mark.style == 0) || (element.mark.style == 4)
            tikzStrings($) = tikzStrings($) + ",";
            tikzStrings($+1) = generate_nested_string("mark options", ...
                                        {"solid", "color"}, ...
                                        {"", element.mark.color.foreground});
            elseif (element.mark.style == 7) || (element.mark.style == 12) || (element.mark.style == 13)
            tikzStrings($) = tikzStrings($) + ",";
            tikzStrings($+1) = generate_nested_string("mark options", ...
                                        {"solid", "rotate", "draw", "fill"}, ...
                                        {"", rotation, element.mark.color.foreground, element.mark.color.background});
            else
            tikzStrings($) = tikzStrings($) + ",";
            tikzStrings($+1) = generate_nested_string("mark options", ...
                                        {"solid", "draw", "fill"}, ...
                                        {"", element.mark.color.foreground, element.mark.color.background});
            end
        end
    end
endfunction
