/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function tikzStrings = axis_options(element)
// Generate axis option entries
//
// Syntax
// tikzStrings = axis_options(element)
//
// Parameters
//      element: struct containing axis information
//      tikzStrings: column vector containing generated strings
//
// Description
// Generate the axis option strings as a column vector. Used by add_options.
//
// Authors
// Manuel Csapo, 2018
    if element.visible == "on"
        // set size (note: temporally disabled due to problems)
        //[width, height] = generate_dimension_string(attributes.figure.size(1), attributes.figure.size(2));
        //tikzStrings = width + ",";
        //tikzStrings($+1) = height + ",";
        tikzStrings($+1) = generate_nested_string("axis background/.style", {"fill"}, ...
                                     {element.color.background}) + ",";
        // scaling
        tikzStrings($+1) = generate_value_string("scale only axis") + ",";
        // axis part
        tikzStrings($+1) = generate_value_string("xmin", element.x_bounds(1)) + ",";
        tikzStrings($+1) = generate_value_string("xmax", element.x_bounds($)) + ",";
        tikzStrings($+1) = generate_value_string("ymin", element.y_bounds(1)) + ",";
        tikzStrings($+1) = generate_value_string("ymax", element.y_bounds($));
        // labels
        if (isfield(element, "x_label") && ~isempty(element.x_label)) ...
           (isfield(element, "y_label") && ~isempty(element.y_label))
            tikzStrings($) = tikzStrings($) + ",";
        tikzStrings($+1) = generate_text_string("xlabel", element.x_label) + ",";
        tikzStrings($+1) = generate_text_string("ylabel", element.y_label) + ",";
        tikzStrings($+1) = generate_nested_string("xlabel style", {"font"}, ...
                                     {element.color.x_label_foreground}) + ",";
        tikzStrings($+1) = generate_nested_string("ylabel style", {"font"}, ...
                                     {element.color.y_label_foreground});
        end
        // title
        if isfield(element, "title") && ~isempty(element.title)
            tikzStrings($) = tikzStrings($) + ",";
            tikzStrings($+1) = generate_nested_string("title style", {"font"}, ...
                                         {element.title_font}) + ",";
            tikzStrings($+1) = generate_text_string("title", element.title);
        end
        // legend
        if isfield(element, "associated_legend") && (element.associated_legend.visible == "on")
            tikzStrings($) = tikzStrings($) + ",";
            tikzStrings($+1) = generate_nested_string("legend style", ...
                                         {"legend cell align", "align", "draw"}, ...
                                         {"left", "left", attributes.legends{index}.color.font});
        end
    end
endfunction
