/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function colors = find_colors(attributes)
// Find colors in a struct
//
// Syntax
// colors = find_colors(fieldname, attributes)
//
// Parameters
// attributes: a struct, which may contain other structs or cells but at least
// one color field
// colors: row vector with color names
//
// Description
// This method can be used to retrieve colors in a given struct. The struct may
// contain structs and cells, but has to have at least on color struct to work. This
// function calls get_colors_from_element to retrieve the color names.
//
// Examples
// plot_example_simple_graph()
// attributes = gather_graphic_attributes();
// colors = find_colors(attributes)
//
// Authors
// Manuel Csapo, 2018
    colors = [];

    // We have to distinguish between structs and cells, the later has structs as elements
    // so we have to iterate over them
    for field = field_iterator(attributes)
        if isstruct(field)
            //TODO change this to colors($+1)
            colors = [colors get_colors_from_element(field)];
        elseif iscell(field)
            for element = field{:}
                //TODO change this to colors($+1)
                colors = [colors get_colors_from_element(element)];
            end
        else
            message = "%s: field is neither struct nor cell!\n";
            error(msprintf(message, "find_colors"))
        end
    end
endfunction
