/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function [lower_bound, upper_bound] = get_axis_bounds(axis, axis_direction)
// Get the lower and upper bounds
//
// Syntax
// [lower_bound, upper_bound] = get_axis_bounds(axis, axis_direction]
//
// Parameters
//      axis: handle for accessing axes data
//      axis_direction: string giving the axis direction, either 'x' or 'y'
//      lower_bound, upper_bound: a row vector containing the upper and lower boundaries for the axis
//
// Description
// Get the lower and upper bound for the given axis direction.
// This function is used in create_axes_struct.
//
// Authors
// Manuel Csapo, 2018
    if ~isdef("axis", "l")
        message = "%s: axis handle required.\n";
        error(msprintf(message, "get_axis_bounds"));
    end
    if ~isdef("axis_direction", "l")
        message = "%s: axis direction (either x or y) required.\n";
        error(msprintf(message, "get_axis_bounds"));
    end

    select axis_direction
        case "x" then
            lower_bound = axis.x_ticks.locations(1);
            upper_bound = axis.x_ticks.locations($);
        case "y" then
            lower_bound = axis.y_ticks.locations(1);
            upper_bound = axis.y_ticks.locations($);
        else
            message = "%s: axis direction must be x or y, but %s was given.\n";
            error(msprintf(message, "getBoundaries", axis_direction));
    end

endfunction
