/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function colors = get_colors_from_element(element)
// Get color indices from a struct element
//
// Syntax
// colors = get_colors_from_element(element)
//
// Parameters
// element: a struct containing other structs
// colors: row vector with color names
//
// Description
// This method can be used to retrieve color names from a given struct. The struct must
// not contain other elements than structs and fields. If a color struct is found, it will
// return its content, otherwise recursively call itself over each element. Used by
// get_colors.
//
// Authors
// Manuel Csapo, 2018
    colors = [];

    if ~isstruct(element)
        message = "%s: input parameter is not a struct!";
        error(msprintf(message, "get_colors_from_element"))
    end

    // check if element contains color, otherwise iterate over its elements
    // and call get_colors_from_element recursively
    if isfield(element, "color")
        colorcontent = getfield("color", element)
        for field = field_iterator(colorcontent)
            //TODO change this to colors($+1)
            colors = [colors field];
        end
    else
        for field = field_iterator(element)
            if ~isstruct(field)
                continue;
            end
            //TODO change this to colors($+1)
            colors = [colors get_colors_from_element(field)];
        end
    end
endfunction
