/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function fileDescriptor = open_file(path, flag)
// Open a file for reading or writing in text mode (will override if it exists)
//
// Syntax
// fileDescriptor = open_file(path)
//
// Parameters
//      path: path with filename
//      flag: either 'read' or 'write'
//      fileDescriptor: handle for the opened file
//
// Description
// Opens a given file for reading or writing. If the given paths directory does not exist,
// it will be created.
//
// Examples
// fd  = open_file(TMPDIR+'/test.txt', 'write')
// write_to_file(fd, ["This is a" "sentence"])
// mclose(fd)
//
// Authors
// Manuel Csapo, 2018
    if ~isdir(dirname(path))
        disp('Directory does not exist, create it ...')
        status = createdir(dirname(path));
        if ~status
            message = "%s: could not create directory, abort!\n";
            error(msprintf(message, "open_file"))
        end
    end

    select flag
       case 'write'
          if isfile(path)
              warning("File already exists, override")
          end
          [fileDescriptor, err] = mopen(path, 'wt');
       case 'read'
          [fileDescriptor, err] = mopen(path, 'rt')
       else
          message = "%s: wrong argument for FLAG!\n";
          error(msprintf(message, "open_file"))
    end

    if err < 0
        message = "%s: could not open file, abort! Error number %d\n";
        error(msprintf(message, "open_file", err))
    end
endfunction
