/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function save_to_file(filename, tikzStrings)
// Save content strings given to the LaTeX file
//
// Syntax
// saveToFile(filename, attributes)
//
// Parameters
//      filename : path to output LaTeX file
//      tikzStrings : column vector containing tikz strings for printing
//
// Description
// The strings must be given as a column vector, otherwise they will not be written
// properly. Filename must be a path to a nonexistent file. If directories in the path do
// not exist, they will be created.
//
// Authors
// Manuel Csapo, 2018
   if ~isdef("filename", "l") || ~isdef("tikzStrings")
      message = "%s: number of arguments < 2.\n";
      error(msprintf(message, "save_to_file"))
   end

    filehandle = open_file(filename, "write")
    write_to_file(filehandle, tikzStrings');
    mclose(filehandle)
endfunction
