/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function colorName = to_color_name(index, colormap)
// Get the color name for the indexed entry in colormap
//
// Syntax
// colorName = to_color_name(index, colormap)
//
// Parameters
//      index: color index relative to colormap
//      colormap: n x 3 matrix containing rgb triples
//
// Description
// This function returns a color name for the given index. The colormap
// holds the rgb triple accesible by the index. If the index is
// negative, the returned name will be either "black", "white" or "gray"
// (respective for -1, -2 or -3). An index of 0 will be "transparent".
//
// Authors
// Manuel Csapo, 2018
    if (size(colormap, "c") ~= 3) || (typeof(colormap) ~= "constant")
        message = "%s: argument #2 is not a valid colormap.\n";
        error(msprintf(message, "to_color_name"));
    end

    if (typeof(index) ~= "constant") || (index > size(colormap, "r"))
        message = "%s: argument #1 is not a valid index.\n";
        error(msprintf(message, "to_color_name"));
    end

    if index < 0
        select index
            case -1 then
                colorName = "black";
            case -2 then
                colorName = "white";
            case -3 then
                colorName = "gray";
            else
                message = "%s: index is lower than -3.\n";
                error(msprintf(message, "to_color_name"));
        end
    elseif index == 0
        colorName = "transparent";
    else
        cmapEntry = colormap(index,:);
        colorName = rgb2name(cmapEntry*255)($);
    end
endfunction
