/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function fonttype = to_fonttype(index)
// Converts a given index to the specific fontype string
//
// Syntax
// fontype = to_fontype(index)
//
// Parameters
//      index: integer value from polyline property "line_style"
//      fontype: string with line type
//
// Description
// The given index will be converted to the corresponding line type string.
// Some types cannot be converted, thus will be "" then.
// fontypes = [\ttfamily, \ttfamily, \sffamily, \sffamily\itshape, \sffamily\bfseries,
// \sffamily\itshape\bfseries, \rmfaily, \rmfamily\itshape, \rmfamily\bfseries,
// \rmfamily\itshape\bfseries]
//
// Examples
// type1 = to_fontype(3) // densely dashed
// type2 = to_fontype(10) // loosely dotted
//
// Authors
// Manuel Csapo, 2018
if ~isdef("index", "l")
    message = "%s: number of arguments < 1";
    error(msprintf(message, "to_fontype"))
end

if index < 1 || index > 10
    message = "%s: index must be between 1 and 10";
    error(msprintf(message, "to_fontype"))
end

fonts = ["\ttfamily", "\ttfamily", "\sffamily", "\sffamily\itshape", ...
         "\sffamily\bfseries", "\sffamily\itshape\bfseries", ...
         "\rmfamily", "\rmfamily\itshap", "\rmfamily\bfseries", ...
         "\rmfamily\itshape\bfseries"];

fonttype = fonts(index);
endfunction
