/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function linetype = to_linetype(index)
// Converts a given index to the specific linetype string
//
// Syntax
// linetype = to_linetype(index)
//
// Parameters
//      index: integer value from polyline property "line_style"
//      linetype: string with line type
//
// Description
// The given index will be converted to the corresponding line type string.
// Some types cannot be converted, thus will be "" then.
// linetypes = [solid, dashed, densely dashed, none, none, none, densely dotted,
// densely dotted, dotted, loosely dotted]
//
// Examples
// type1 = to_linetype(3) // densely dashed
// type2 = to_linetype(10) // loosely dotted
//
// Authors
// Manuel Csapo, 2018

if ~isdef("index", "l")
    message = "%s: number of arguments < 1";
    error(msprintf(message, "to_linetype"))
end

if index < 1 || index > 10
    message = "%s: index must be between 1 and 10";
    error(msprintf(message, "to_linetype"))
end

lines = ["solid", "dashed", "densely dashed", "dashdotted", ...
         "dashdotdotted", "dash pattern = on 6pt off 3pt on 1pt off 3pt", ...
         "densely dotted", "densely dotted", "dotted", "loosely dotted"];

linetype = lines(index);
endfunction
