/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function marktype = to_marktype(index)
// Converts a given index to the specific marktype string
//
// Syntax
// marktype = to_marktype(index)
//
// Parameters
//      index: integer value from polyline property "mark_style"
//      marktype: string with markt type
//
// Description
// The given index will be converted to the corresponding mark type string.
// Some types cannot be converted, thus will be "" then.
// marktypes = [filled circle, cross, x, circle with cross, filled diamond,
// diamond, triangle, none, none, circle, star, square, none, none, none]
//
// Examples
// type1 = to_marktype(2) // x
// type2 = to_marktype(9) // circle
//
// Authors
// Manuel Csapo, 2018

if ~isdef("index", "l")
    message = "%s: number of arguments < 1";
    error(msprintf(message, "to_marktype"))
end

if index < 0 || index > 14
    message = "%s: index must be between 1 and 14";
    error(msprintf(message, "to_marktype"))
end

marks = ["*", "+", "x", "oplus*", "diamond*", "diamond*", ...
         "triangle*", "triangle*", "diamondplus*", "*", "star", ...
         "square*", "triangle*", "triangle*", "heart"];

// mark types start at 0
marktype = marks(index+1);
endfunction
