/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function write_to_file(fileDescriptor, content)
// Write the given content to an opened file via file descriptor
//
// Syntax
// write_to_file(fileDescriptor, content)
//
// Parameters
//      fileDescriptor: handle for the opened file
//      content: vector containing data which will be written to the file
//
// Description
// Writes the data from vector to the file given by the file descriptor.
// Returns errors if file is not writeable, file was not opened, etc.
//
// Examples
// fd = open_file_for_output(TMPDIR+'/test.txt')
// write_to_file(fd, ["This is a" "sentence"])
// mclose(fd)
//
// Authors
// Manuel Csapo, 2018
    if isempty(content)
        message = "%s: nothing to write, abort!\n";
        error(msprintf(message, "write_to_file"))
    end

    if ~fileDescriptor
        message = "%s: no valid file descriptor, abort!\n";
        error(msprintf(message, "write_to_file"))
    end

    if iscolumn(content)
        content = content';
    end

    mputl(content, fileDescriptor);
endfunction
