/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function [f, a] = plot_example_champ(figureNumber)
// Generate a vector field
//
// Syntax
// [f, a] = plot_examples_simple_graph(figureNumber);
//
// Parameters
//      figureNumber: number of figure used for displaying
//      f, a: figure and axis handles
//
// Description
// Plotting example which generates a vector field between -2 and 2.
// Can be used for xs2tikz as an example.
//
//
// Authors
// Manuel Csapo, 2018
    // Load internals
    path = get_function_path("plot_example3d_mesh");
    path = fullpath(fullfile(fileparts(path)));
    xs2tikzinternalslib = lib(fullfile(path, "internals"));

    if ~isdef("figureNumber", "l")
        f = prepare_figure(0)
    else
        if typeof(figureNumber) ~= "constant"
            message = "%s: input argument figureNumber is not a constant!\n";
            error(msprintf(message, "plot_example_champ"))
        end

        f = prepare_figure(figureNumber)
    end

    x = -2:0.5:2;
    y = -2:0.5:2;
    [X, Y] = meshgrid(x, y);
    Vx = -Y;
    Vy = X;
    champ(x, y, Vx', Vy');
    label_figure(['Just a vector field' 'x' 'y']);
    a = gca()
endfunction
