/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function [f, a] = plot_example_color_map(figureNumber)
// Generate a sgrayplot with colormap
//
// Syntax
// [f, a] = plot_examples_simple_graph(figureNumber);
//
// Parameters
//      figureNumber: number of figure used for displaying
//      f, a: figure and axis handles
//
// Description
// Plotting example which generates a sgrayplot with colormap.
// Can be used for xs2tikz as an example.
//
// Authors
// Manuel Csapo, 2018
    // Load internals
    path = get_function_path("plot_example_color_map");
    path = fullpath(fullfile(fileparts(path)));
    xs2tikzinternalslib = lib(fullfile(path, "internals"));

    if ~isdef("figureNumber", "l")
        f = prepare_figure(0)
    else
        if typeof(figureNumber) ~= "constant"
            message = "%s: input argument figureNumber is not a constant!\n";
            error(msprintf(message, "plot_example_color_map"))
        end

        f = prepare_figure(figureNumber)
    end

    x = linspace(0, 1, 81);
    z = cos(2*%pi*x)'*sin(2*%pi*x);
    zm = min(z); zM = max(z);
    clf()
    gcf().color_map = jetcolormap(64);
    colorbar(zm, zM)
    Sgrayplot(x, x, z)
    xtitle("The function cos(2 pi x) * sin(2 pi y)")
    a = gca()
endfunction
