/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function [f, a] = plot_example_mesh(figureNumber)
// Generate a sombrero (3D Mesh) between -PI and +PI
//
// Syntax
// [f, a] = plot_examples_simple_graph(figureNumber);
//
// Parameters
//      figureNumber: number of figure used for displaying
//      f, a: figure and axis handles
//
// Description
// Plotting example which generates a 3D function (sombreror) between -PI and +PI.
// Can be used for xs2tikz as an example.
//
//
// Authors
// Manuel Csapo, 2018
    // Load internals
    path = get_function_path("plot_example3d_mesh");
    path = fullpath(fullfile(fileparts(path)));
    xs2tikzinternalslib = lib(fullfile(path, "internals"));

    if ~isdef("figureNumber", "l")
        f = prepare_figure(0)
    else
        if typeof(figureNumber) ~= "constant"
            message = "%s: input argument figureNumber is not a constant!\n";
            error(msprintf(message, "plot_example_mesh"))
        end

        f = prepare_figure(figureNumber)
    end

    xy = linspace(-%pi, %pi, 40);
    [X, Y] = meshgrid(xy);
    F = sin(X.^2+Y.^2)./(X.^2+Y.^2);
    mesh(X, Y, F);
    label_figure(['Just a sombrero' 'x' 'y']);
    a = gca()
endfunction
