/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function [f, a] = plot_example_simple_graph(figureNumber)
// Generate a simple graph with plot2d
//
// Syntax
// [f, a] = plot_examples_simple_graph(figureNumber);
//
// Parameters
//      figureNumber: number of figure used for displaying
//      f, a: figure and axis handles
//
// Description
// Plotting example which generates different trigonometric functions between 0 and 2*PI.
// Can be used for xs2tikz as an example.
//
// Authors
// Manuel Csapo, 2018
    // Load internals
    path = get_function_path("plot_example_simple_graph");
    path = fullpath(fullfile(fileparts(path)));
    xs2tikzinternalslib = lib(fullfile(path, "internals"));

    if ~isdef("figureNumber", "l")
        f = prepare_figure(0)
    else
        if typeof(figureNumber) ~= "constant"
            message = "%s: input argument figureNumber is not a constant!\n";
            error(msprintf(message, "plot_example_simple_graph"))
        end

        f = prepare_figure(figureNumber)
    end

    x = linspace(0, %pi, 100);
    plot(x, sin(x), '-.g+', x, cos(x), '--rv', x, tan(x), '-bx');
    label_figure(["$\textbf{sine, cosine and tan}$" 'x' 'f(x)']);
    legend(['sin(x)', 'co(x)', 'tan(x)'])
    a = gca();
endfunction
