/* Copyright 2018 Manuel-Tobias Csapo

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/
function [f, a] = plot_example_subplots(figureNumber)
// Generate a subplot with trigonometric functions
//
// Syntax
// [f, a] = plot_examples_subplots(figureNumber);
//
// Parameters
//      figureNumber: number of figure used for displaying
//      f, a: figure and axis handles
//
// Description
// Plotting example which generates a subplot with trigonometric functions
// between 0 and 2*PI. Can be used for xs2tikz as an example.
//
// Authors
// Manuel Csapo, 2018
    // Load internals
    path = get_function_path("plot_example_subplots");
    path = fullpath(fullfile(fileparts(path)));
    xs2tikzinternalslib = lib(fullfile(path, "internals"));

    if ~isdef("figureNumber", "l")
        f = prepare_figure(0)
    else
        if typeof(figureNumber) ~= "constant"
            message = "%s: input argument figureNumger is not a constant!\n";
            error(msprintf(message, "plot_example_subplots"))
        end

        f = prepare_figure(figureNumber)
    end

    x = linspace(0, 2*%pi, 100);
    subplot(231)
    plot(x, sin(x), '-.r')
    label_figure(["sine" 'x' 'f(x)']);
    subplot(232)
    plot(x, cos(x), '-.b')
    label_figure(["cosine" 'x' 'f(x)']);
    subplot(233)
    plot(x, tan(x), '-.g')
    label_figure(["tangent" 'x' 'f(x)']);
    subplot(234)
    plot(x, sinh(x), '-.g')
    label_figure(["sinh" 'x' 'f(x)']);
    subplot(235)
    plot(x, cosh(x), '-.g')
    label_figure(["cosh" 'x' 'f(x)']);
    a = gca();
endfunction
