// Unit test for option adding in string generation
// Author: Manuel-Tobias Csapo, 2018
// TODO: strstr() calls could be substituted by strindex() which
// returns location instead of substring. Use them to check for equality instead
// of simple existence

//
// Test 1 - No marks set (addplot_options)
x = linspace(0, 2*%pi);
plot(x, sin(x))

attributes = gather_graphic_attributes();
computed = add_options("addplot", 1, attributes);

assert_checktrue(isempty(strstr(computed, "mark")))

clf();

// Test 2 - Rotated marks (addplot_options)
y = 1:10;
m = 0.8;
z = -2;
f = m * y + z;

plot(y, f, '-mv')

attributes = gather_graphic_attributes();
computed = add_options("addplot", 1, attributes);

assert_checktrue(~isempty(strstr(computed, "rotate=180")))

clf();

// Test 3 - No title (axis_options)
plot(x, sin(x))

attributes = gather_graphic_attributes();
computed = add_options("axis", 1, attributes);

assert_checktrue(isempty(strstr(computed, "title")))
clf();

// Test 4 - With title (axis_options)
plot(x, sin(x))
title('Much title. Very sine')

attributes = gather_graphic_attributes();
computed = add_options("axis", 1, attributes);

assert_checktrue(~isempty(strstr(computed, "title")))

clf();

// Test 5 - No legend (axis_options)
plot(x, sin(x))

attributes = gather_graphic_attributes();
computed = add_options("axis", 1, attributes);

assert_checktrue(isempty(strstr(computed, "legend style")))

clf();

// Test 6 - Has legend (axis_options)

plot(x, sin(x))
legend(['sin(x)'])

attributes = gather_graphic_attributes();
computed = add_options("axis", 1, attributes);

assert_checktrue(~isempty(strstr(computed, "legend style")))

clf();
