// Unit tests for polylines struct
// Author: Manuel-Tobias Csapo, 2018

// load internals
path = get_function_path("create_polylines_struct");
path = fullpath(fullfile(fileparts(path)));
xs2tikzinternalslib = lib(fullfile(path, "internals"));

//
// Test 1 - One polyline
x = linspace(0, 2*%pi);

plot(x, sin(x));

expected = [];

index = find(gca().children.type == "Compound");
compound = gca().children(index);
index = find(compound.children.type == "Polyline");
polyline = compound.children(index);

expected = struct(...
           "handle", polyline, ...
           "associated_axis", gca(), ...
           "visible", polyline.visible, ...
           "data", polyline.data, ...
           "line", struct(), ...
           "mark", struct());

expected.line.color = struct();
expected.mark.color = struct();
expected.mark.style = polyline.mark_style;

expected.line.color.foreground = to_color_name(polyline.foreground, gcf().color_map);
expected.line.color.background = to_color_name(polyline.background, gcf().color_map);
expected.line.style = polyline.line_style;
expected.mark.mode = polyline.mark_mode;
expected.mark.color.foreground = to_color_name(polyline.mark_foreground, gcf().color_map);
expected.mark.color.background = to_color_name(polyline.mark_background, gcf().color_map);

computed = create_polylines_struct(create_axes_struct(gcf()), gcf().color_map);
disp(computed{:})
disp(expected)

// TODO should be working in normal environment,
// does not in test. Fix or delete
//assert_checkequal(computed{:}, expected)

for name = fieldnames(expected)'
    expectedField = getfield(name, expected);
    computedField = getfield(name, computed{:});
    assert_checkequal(computedField, expectedField)
end

for name = fieldnames(expected.line)'
    expectedField = getfield(name, expected.line);
    computedField = getfield(name, computed{:}.line);
    assert_checkequal(computedField, expectedField)
end

for name = fieldnames(expected.line.color)'
    expectedField = getfield(name, expected.line.color);
    computedField = getfield(name, computed{:}.line.color);
    assert_checkequal(computedField, expectedField)
end

for name = fieldnames(expected.mark.color)'
    expectedField = getfield(name, expected.mark.color);
    computedField = getfield(name, computed{:}.mark.color);
    assert_checkequal(computedField, expectedField)
end

clf();

// Test 2 - Multiple Polylines
plot(x, sin(x), x, cos(x))

computed = create_polylines_struct(create_axes_struct(gcf()), gcf().color_map);

assert_checkequal(size(computed, "r"), 2)

clf();

// Test 3 - Invisible Polylines
x = linspace(0, 2*%pi);

plot(x, sin(x))

index = find(gca().children.type == "Compound");
compound = gca().children(index);
index = find(compound.children.type == "Polyline");
polyline = compound.children(index);

polyline.visible = "off";

computed = create_polylines_struct(create_axes_struct(gcf()), gcf().color_map);

assert_checkequal(computed, {})

clf();
