// Unit test for TikZ string generation
// Author: Manuel-Tobias Csapo, 2018

//
// Test 1 - Minimal document
x = [1, 2, 3, 4];
f = 0.8 * x + 2;

plot(x, f)
title("Sample Plot");
legend(["line"]);

expected = cell();
expected{1} = [
    "\documentclass[12pt,a4paper]{scrartcl}" ; ...
    "\usepackage[T1]{fontenc}" ;  ...
    "\usepackage[utf8]{inputenc}" ; ...
    "\usepackage{pgfplots}" ; ...
    "\usepackage{grffile}" ; ...
    "\pgfplotsset{compat=newest}" ; ...
    "\usetikzlibrary{plotmarks}" ; ...
    "\usetikzlibrary{arrows.meta}" ; ...
    "\usepgfplotslibrary{patchplots}" ; ...
    "\usepackage{amsmath}" ; ...
    "" ...
];
expected{2} = [
    "\definecolor{black}{rgb}{0.000000,0.000000,0.000000}%" ; ...
    "\definecolor{blue1}{rgb}{0.000000,0.000000,1.000000}%" ; ...
    "\definecolor{white}{rgb}{1.000000,1.000000,1.000000}%" ; ...
    "" ...
];
expected{3} = ["\begin{document}"];
expected{4} = ["\begin{tikzpicture}"];
expected{5} = ["\centering"];
expected{6} = ["\begin{axis}[%"];
expected{7} = [
    "axis background/.style = {fill=white}," ; ...
    "scale only axis," ; ...
    "xmin=1," ; ...
    "xmax=4," ; ...
    "ymin=3," ; ...
    "ymax=5," ; ...
    "title style = {font=\ttfamily}," ; ...
    "title={Sample Plot}," ; ...
    "legend style = {legend cell align=left, align=left, draw=black}" ; ...
    "]" ...
];
expected{8} = [
    "\addplot[%" ; ...
    "draw=blue1," ; ...
    "fill=white," ; ...
    "solid" ; ...
    "]" ; ...
    "coordinates {" ; ...
    "(1.000000, 2.800000)" ; ...
    "(2.000000, 3.600000)" ; ...
    "(3.000000, 4.400000)" ; ...
    "(4.000000, 5.200000)" ; ...
    "};" ; ...
    "\addlegendentry{line}" ; ...
    "" ...
];
expected{9} = ["\end{axis}"];
expected{10} = ["\end{tikzpicture}"];
expected{11} = ["\end{document}"];

computed = generate_tikz_strings(%t, gather_graphic_attributes());

assert_checkequal(computed{:}, expected{:})
